aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/graph
diff options
context:
space:
mode:
authorGeorgios Pinitas <georgios.pinitas@arm.com>2018-01-10 15:33:28 +0000
committerAnthony Barbier <anthony.barbier@arm.com>2018-11-02 16:43:42 +0000
commit652bde553f506caac4c563988dc9baf746f9584d (patch)
tree931d17bdfa70e9968cd434cfa53db8919bb534ea /arm_compute/graph
parentf72f9367d1eddee91f15a64952b99ee6b80b821d (diff)
downloadComputeLibrary-652bde553f506caac4c563988dc9baf746f9584d.tar.gz
COMPMID-674 - Create Google InceptionV3 example
Change-Id: I389e0d4104b7dde60b7cdd612a83f3328517e44c Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/115804 Tested-by: Jenkins <bsgcomp@arm.com> Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
Diffstat (limited to 'arm_compute/graph')
-rw-r--r--arm_compute/graph/SubTensor.h33
1 files changed, 18 insertions, 15 deletions
diff --git a/arm_compute/graph/SubTensor.h b/arm_compute/graph/SubTensor.h
index 72aa789274..43b835d49c 100644
--- a/arm_compute/graph/SubTensor.h
+++ b/arm_compute/graph/SubTensor.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2017 ARM Limited.
+ * Copyright (c) 2017-2018 ARM Limited.
*
* SPDX-License-Identifier: MIT
*
@@ -44,19 +44,21 @@ public:
SubTensor();
/** Constructor
*
* @param[in] parent Parent to create sub-tensor from
* @param[in] tensor_shape Sub-tensor shape
* @param[in] coords Starting coordinates of the sub-tensor in the parent tensor
*/
- SubTensor(Tensor &parent, TensorShape tensor_shape, Coordinates coords);
+ SubTensor(Tensor &parent, TensorShape tensor_shape, Coordinates coords, bool extend_parent = false);
/** Constructor
*
* @param[in] parent Parent to create sub-tensor from
* @param[in] tensor_shape Sub-tensor shape
* @param[in] coords Starting coordinates of the sub-tensor in the parent tensor
* @param[in] target Execution target
*/
- SubTensor(arm_compute::ITensor *parent, TensorShape tensor_shape, Coordinates coords, TargetHint target);
+ SubTensor(arm_compute::ITensor *parent, TensorShape tensor_shape, Coordinates coords, TargetHint target, bool extend_parent = false);
/** Prevent instances of this class from being copied (As this class contains pointers) */
SubTensor(const SubTensor &) = delete;
/** Prevent instances of this class from being copied (As this class contains pointers) */
@@ -82,11 +84,12 @@ private:
void instantiate_subtensor();
private:
- TargetHint _target; /**< Target that this tensor is pinned on */
- TensorShape _tensor_shape; /**< SubTensor shape */
- Coordinates _coords; /**< SubTensor Coordinates */
- arm_compute::ITensor *_parent; /**< Parent tensor */
- std::unique_ptr<arm_compute::ITensor> _subtensor; /**< SubTensor */
+ TargetHint _target; /**< Target that this tensor is pinned on */
+ TensorShape _tensor_shape; /**< SubTensor shape */
+ Coordinates _coords; /**< SubTensor Coordinates */
+ arm_compute::ITensor *_parent; /**< Parent tensor */
+ std::unique_ptr<arm_compute::ITensor> _subtensor; /**< SubTensor */
+ bool _extend_parent; /**< Parent extension flag */
};
} // namespace graph
} // namespace arm_compute
@@ -44,19 +44,21 @@ public:
/** Constructor
*
- * @param[in] parent Parent to create sub-tensor from
- * @param[in] tensor_shape Sub-tensor shape
- * @param[in] coords Starting coordinates of the sub-tensor in the parent tensor
+ * @param[in] parent Parent to create sub-tensor from
+ * @param[in] tensor_shape Sub-tensor shape
+ * @param[in] coords Starting coordinates of the sub-tensor in the parent tensor
+ * @param[in] extend_parent (Optional) Extend parent with subtensor shape if subtensor indexes out of bounds
*/
@@ -44,19 +44,21 @@ public:
/** Constructor
*
- * @param[in] parent Parent to create sub-tensor from
- * @param[in] tensor_shape Sub-tensor shape
- * @param[in] coords Starting coordinates of the sub-tensor in the parent tensor
- * @param[in] target Execution target
+ * @param[in] parent Parent to create sub-tensor from
+ * @param[in] tensor_shape Sub-tensor shape
+ * @param[in] coords Starting coordinates of the sub-tensor in the parent tensor
+ * @param[in] target Execution target
+ * @param[in] extend_parent (Optional) Extend parent with subtensor shape if subtensor indexes out of bounds
*/